@@ -162,15 +162,6 @@ hcai_impute <- function(recipe,
     if (nominal_method == "new_category") {
       recipe <- step_missing(recipe, all_nominal(), - all_outcomes())
     } else if (nominal_method == "bagimpute") {
-      if ("character" %in% map_chr(recipe$template, ~{
-        class(.x) %>% first()
-      }))
-        warning("`bagimpute` depends on another library that does not support",
-                " character columns yet. Check `bagimpute` by setting ",
-                "`collapse_rare_factors = FALSE`, and verify that missing ",
-                "values have been imputed with `missingness()`. If `bagimpute`",
-                " does not impute missing values, please convert all character",
-                " columns to factors.")
       recipe <- step_bagimpute(
         recipe,
         all_nominal(),
@@ -179,11 +170,7 @@ hcai_impute <- function(recipe,
         options = nom_p$bag_options,
         impute_with = nom_p$impute_with,
         seed_val = nom_p$seed_val)
-    }  else if (nominal_method == "knnimpute") {
-      if ("character" %in% map_chr(recipe$template, ~class(.x) %>% first()))
-        message("`knnimpute` depends on another library that does not support ",
-                "character columns yet. If `knnimpute` fails please convert ",
-                "all character columns to factors for knn imputation.")
+    } else if (nominal_method == "knnimpute") {
       recipe <- step_knnimpute(
         recipe,
         all_nominal(), - all_outcomes(),
